@@ -1,6 +1,7 @@
 import copy
 import json
 import re
+import types
 from logging import error, info
 
 import requests
@@ -110,7 +111,7 @@ def request(method, user_id, url, requests_common_kwargs=None, **kwargs):
 class ActResultSet(object):
     """Represents a list of Act entries"""
 
-    def __init__(self, response, deserializer):
+    def __init__(self, response, deserializer, config=None):
         """Initialize result set
         Args:
             response (str):       JSON response from Act. This should include
@@ -126,7 +127,7 @@ class ActResultSet(object):
         if not isinstance(response["data"], list):
             raise ResponseError("Response should be list: {}".format(response["data"]))
 
-        self.data = [deserializer(**d) for d in response["data"]]
+        self.data = [deserializer(**d).configure(config) for d in response["data"]]
 
         self.size = response["size"]
         self.count = response["count"]
