@@ -4,12 +4,14 @@ import json
 import re
 import time
 from logging import error, info, warning
+from typing import Union, Any
 
 import act.api
 from act.api.re import UUID_MATCH
 
 from . import DEFAULT_FACT_VALIDATOR
-from .base import ActBase, Comment, NameSpace, Organization, Origin, origin_serializer
+from .base import (ActBase, Comment, NameSpace, Organization, Origin,
+                   origin_serializer)
 from .obj import Object, ObjectType
 from .schema import Field, MissingField, ValidationError, schema_doc
 
@@ -19,6 +21,11 @@ class IllegalFactChain(Exception):
         Exception.__init__(self, *args, **kwargs)
 
 
+class UnknownType(Exception):
+    def __init__(self, *args, **kwargs):
+        Exception.__init__(self, *args, **kwargs)
+
+
 class RelevantObjectBindings(ActBase):
     SCHEMA = [
         Field(
@@ -586,7 +593,7 @@ class Fact(AbstractFact):
             raise MissingField("Must have fact ID to get comments")
 
         res = self.api_get("v1/fact/uuid/{}/meta".format(self.id), params=params)
-        return act.api.base.ActResultSet(res, MetaFact)
+        return act.api.base.ActResultSet(res, MetaFact, config=self.config)
 
 
 class MetaFact(AbstractFact):
@@ -647,6 +654,16 @@ class MetaFact(AbstractFact):
         return self
 
 
+def auto_fact_type(**kwargs: Any) -> Union[MetaFact, Fact]:
+    """Guess type based on keys in dictionary and return Object"""
+    if kwargs.get("inReferenceTo"):
+        return MetaFact(**kwargs)
+    elif any([kwargs.get("sourceObject"), kwargs.get("destinationObject")]):
+        return Fact(**kwargs)
+    else:
+        raise UnknownType("Unable to guess element type: {}".format(kwargs))
+
+
 def fact_chain_seed(*facts):
     """
         Get seed of the fact chain. The seed is the string representations of all facts sorted
